@@ -1,18 +1,16 @@
 library(daff)
-# set.seed(42)
-#
-# df.orig <- data.frame(letters=letters,
-#                      ints=1:26,
-#                      doubles=(1:26)+0.5,
-#                      factors=factor(LETTERS),
-#                      LETTERS=LETTERS,
-#                      lL=paste (letters, LETTERS),
-#                      stringsAsFactors = FALSE,
-#                      unchanged=paste0(letters, LETTERS)
-#                      )
-# saveRDS(df.orig, file="tests/more_tests.Rds")
-# print(getwd())
-df.orig <- readRDS("more_tests.Rds")
+suppressWarnings(RNGversion("3.5.0"))
+set.seed(42)
+
+df.orig <- data.frame(letters=letters,
+                     ints=1:26,
+                     doubles=(1:26)+0.5,
+                     factors=factor(LETTERS),
+                     LETTERS=LETTERS,
+                     lL=paste (letters, LETTERS),
+                     stringsAsFactors = FALSE,
+                     unchanged=paste0(letters, LETTERS)
+                     )
 df.ref <- df.orig
 df     <- df.orig
 
